itkwasm.pixel_types - itkwasm python documentation
Description: Module Contents: Classes:,, PixelTypes,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.pixel_types`

## Module Contents

### Classes

`PixelTypes` |

### API

class itkwasm.pixel_types.PixelTypes

  Bases: `str`, `enum.Enum`

  Unknown

    ‘Unknown’

  Scalar

    ‘Scalar’

  RGB

    ‘RGB’

  RGBA

    ‘RGBA’

  Offset

    ‘Offset’

  Vector

    ‘Vector’

  Point

    ‘Point’

  CovariantVector

    ‘CovariantVector’

  SymmetricSecondRankTensor

    ‘SymmetricSecondRankTensor’

  DiffusionTensor3D

    ‘DiffusionTensor3D’

  Complex

    ‘Complex’

  FixedArray

    ‘FixedArray’

  Array

    ‘Array’

  Matrix

    ‘Matrix’

  VariableLengthVector

    ‘VariableLengthVector’

  VariableSizeMatrix

    ‘VariableSizeMatrix’

  __str__()
  __repr__()